BFGraph: FastqFile Class Reference

BFGraph

Public Member Functions | Data Fields
FastqFile Class Reference

## Public Member Functions
| FastqFile (const vector< string > fnames)
void | close ()
void | reopen ()
int | read_next (char *read, size_t *read_len, string &seq, size_t *seq_len, unsigned int *file_id, char *qual=NULL)

## Data Fields
vector< string >::const_iterator | fnit
unsigned int | file_no

The documentation for this class was generated from the following files:

- src/fastq.hpp
- src/fastq.cpp